@@ -1,8 +1,6 @@
 from autobahn.asyncio.websocket import WebSocketServerProtocol
 
 import compas
-from compas.utilities import DataEncoder
-from compas.utilities import DataDecoder
 import importlib
 import json
 from compas_cloud import Sessions
@@ -11,6 +9,13 @@ import sys
 import traceback
 import pkg_resources
 
+try:
+    from compas.data import DataEncoder
+    from compas.data import DataDecoder
+except ImportError:
+    from compas.utilities import DataEncoder
+    from compas.utilities import DataDecoder
+
 
 class CompasServerProtocol(WebSocketServerProtocol):
     """The CompasServerProtocol defines the behaviour of compas cloud server"""
@@ -188,13 +193,12 @@ class CompasServerProtocol(WebSocketServerProtocol):
     def version(self):
 
         working_set = pkg_resources.working_set
-        packages = set([p.project_name for p in working_set]) - set(['COMPAS'])
-        compas_pkgs = [p for p in packages if p.lower().startswith('compas')]
+        packages = {p.project_name: p.version for p in working_set if p.project_name.lower().startswith('compas')}
 
         return {
             "COMPAS": compas.__version__,
             "Python": sys.version,
-            "Extensions": compas_pkgs
+            "Packages": packages
         }
 
 
